# njx

NJX is a library for morphologically and bio-physically detailed neuron simulations in JAX.

## Acknowledgements

This library incorporates code from the excellent [jax-cfd](https://github.com/google/jax-cfd) library. In particular we make use of their solver code and some utilities. The respective files carry the original copyright notices.
